==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/test/t_HistoryStrategy_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_HistoryStrategy_std.cxx
 *  @brief The test file of class HistoryStrategy for standard methods
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu 26 jun 2008) $
 *  Id:      $Id: t_HistoryStrategy_std.cxx 862 2008-06-26 11:50:17Z dutka $
 */
#include <iostream>
#include <sstream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "HistoryStrategy.hxx"
#include "NumericalSample.hxx"
#include "Null.hxx"
#include "Full.hxx"
#include "Last.hxx"
#include "Compact.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Type;
using namespace OT::Base::Stat;


int main(int argc, char *argv[])
{
  TESTPREAMBLE;

  try {
    UnsignedLong size(10);
    UnsignedLong dimension(2);
    NumericalSample sample(size, dimension);
    // Fill-in the sample
    for (UnsignedLong i = 0; i < size; ++i)
      {
	for (UnsignedLong j = 0; j < dimension; ++j)
	  {
	    sample[i][j] = i + NumericalScalar(j) / dimension;
	  }
      }
    std::cout << "sample=" << sample << std::endl;
    // History using the Null strategy
    Null nullStrategy;
    for (UnsignedLong i = 0; i < size; ++i)
      {
	nullStrategy.store(sample[i]);
      }
    std::cout << "Null strategy sample=" << nullStrategy.getSample() << std::endl;
    // History using the Full strategy
    Full fullStrategy;
    for (UnsignedLong i = 0; i < size; ++i)
      {
	fullStrategy.store(sample[i]);
      }
    std::cout << "Full strategy sample=" << fullStrategy.getSample() << std::endl;
    // History using the Last strategy, large storage
    Last lastStrategy(3 * size);
    for (UnsignedLong i = 0; i < size; ++i)
      {
	lastStrategy.store(sample[i]);
      }
    std::cout << "Last strategy sample (large storage)=" << lastStrategy.getSample() << std::endl;
    lastStrategy = Last(size / 3);
    // History using the Last strategy, small storage
    for (UnsignedLong i = 0; i < size; ++i)
      {
	lastStrategy.store(sample[i]);
      }
    std::cout << "Last strategy sample (small storage)=" << lastStrategy.getSample() << std::endl;
    // History using the Compact strategy, large storage
    Compact compactStrategy(3 * size);
    for (UnsignedLong i = 0; i < size; ++i)
      {
	compactStrategy.store(sample[i]);
      }
    std::cout << "Compact strategy sample (large storage)=" << compactStrategy.getSample() << std::endl;
    compactStrategy = Compact(size / 3);
    // History using the Compact strategy, small storage
    for (UnsignedLong i = 0; i < size; ++i)
      {
	compactStrategy.store(sample[i]);
      }
    std::cout << "Compact strategy sample (small storage)=" << compactStrategy.getSample() << std::endl;
  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/test/t_HistoryStrategy_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_HistoryStrategy_std.cxx
 *  @brief The test file of class HistoryStrategy for standard methods
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: t_HistoryStrategy_std.cxx 1262 2009-05-28 12:47:53Z dutka $
 */
#include <iostream>
#include <sstream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include "HistoryStrategy.hxx"
#include "NumericalSample.hxx"
#include "Null.hxx"
#include "Full.hxx"
#include "Last.hxx"
#include "Compact.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Type;
using namespace OT::Base::Stat;


int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  try {
    UnsignedLong size(10);
    UnsignedLong dimension(2);
    NumericalSample sample(size, dimension);
    // Fill-in the sample
    for (UnsignedLong i = 0; i < size; ++i)
      {
	for (UnsignedLong j = 0; j < dimension; ++j)
	  {
	    sample[i][j] = i + NumericalScalar(j) / dimension;
	  }
      }
    fullprint << "sample=" << sample << std::endl;
    // History using the Null strategy
    Null nullStrategy;
    for (UnsignedLong i = 0; i < size; ++i)
      {
	nullStrategy.store(sample[i]);
      }
    fullprint << "Null strategy sample=" << nullStrategy.getSample() << std::endl;
    // History using the Full strategy
    Full fullStrategy;
    for (UnsignedLong i = 0; i < size; ++i)
      {
	fullStrategy.store(sample[i]);
      }
    fullprint << "Full strategy sample=" << fullStrategy.getSample() << std::endl;
    // History using the Last strategy, large storage
    Last lastStrategy(3 * size);
    for (UnsignedLong i = 0; i < size; ++i)
      {
	lastStrategy.store(sample[i]);
      }
    fullprint << "Last strategy sample (large storage)=" << lastStrategy.getSample() << std::endl;
    lastStrategy = Last(size / 3);
    // History using the Last strategy, small storage
    for (UnsignedLong i = 0; i < size; ++i)
      {
	lastStrategy.store(sample[i]);
      }
    fullprint << "Last strategy sample (small storage)=" << lastStrategy.getSample() << std::endl;
    // History using the Compact strategy, large storage
    Compact compactStrategy(3 * size);
    for (UnsignedLong i = 0; i < size; ++i)
      {
	compactStrategy.store(sample[i]);
      }
    fullprint << "Compact strategy sample (large storage)=" << compactStrategy.getSample() << std::endl;
    compactStrategy = Compact(size / 3);
    // History using the Compact strategy, small storage
    for (UnsignedLong i = 0; i < size; ++i)
      {
	compactStrategy.store(sample[i]);
      }
    fullprint << "Compact strategy sample (small storage)=" << compactStrategy.getSample() << std::endl;
  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}
